@@ -11,7 +11,7 @@ from .cover import Cover
 from .network import NetworkChapter
 from .search import SearchMapping
 
-INCLUDE_ALL = ["cover_art", "manga", "chapter", "scanlation_group", "author", "artist", "user"]
+INCLUDE_ALL = ["cover_art", "manga", "chapter", "scanlation_group", "author", "artist", "user", "leader", "member"]
 
 
 class MDException(Exception):
@@ -59,13 +59,15 @@ class MangaDex:
     def login(self, username: str, password: str) -> bool:
         """Logs in to MangaDex using an username and a password."""
         credentials = {"username": username, "password": password}
-        post = self.session.post(f"{self.api}/auth/login", data=json.dumps(credentials))
+        post = self.session.post(f"{self.api}/auth/login", data=json.dumps(credentials),
+                                 headers={"Content-Type": "application/json"})
         return self._store_token(post)
 
     def login_token(self, token: str) -> bool:
         """Logs in to MangaDex using a refresh token."""
         credentials = {"token": token}
-        post = self.session.post(f"{self.api}/auth/refresh", data=json.dumps(credentials))
+        post = self.session.post(f"{self.api}/auth/refresh", data=json.dumps(credentials),
+                                 headers={"Content-Type": "application/json"})
         return self._store_token(post)
 
     def logout(self):
@@ -78,7 +80,8 @@ class MangaDex:
             raise NotLoggedInError
         token = token or self.refresh_token
         data = {"token": token}
-        post = self.session.post(f"{self.api}/auth/refresh", data=json.dumps(data))
+        post = self.session.post(f"{self.api}/auth/refresh", data=json.dumps(data),
+                                 headers={"Content-Type": "application/json"})
         return self._store_token(post)
 
     def check_session(self) -> bool:
@@ -190,18 +193,22 @@ class MangaDex:
     def network_report(self, url: str, success: bool, cache_header: bool, req_bytes: int, req_duration: int) -> bool:
         """Reports statistics back to the MD@H Network."""
         data = {"url": url, "success": success, "cached": cache_header, "bytes": req_bytes, "duration": req_duration}
-        req = self.session.post(f"{self.net_api}/report", data=json.dumps(data))
+        req = self.session.post(f"{self.net_api}/report", data=json.dumps(data),
+                                headers={"Content-Type": "application/json"})
         if req.status_code == 200:
             return True
         else:
             raise APIError(req)
 
-    def get_group(self, uuid: str) -> Group:
+    def get_group(self, uuid: str, includes: list = None) -> Group:
         """Gets a group with a specific uuid."""
-        req = self.session.get(f"{self.api}/group/{uuid}")
+        params = None
+        if includes:
+            params = {"includes[]": includes}
+        req = self.session.get(f"{self.api}/group/{uuid}", params=params)
         if req.status_code == 200:
             resp = req.json()
-            return Group(resp["data"], None, self)
+            return Group(resp["data"], resp["relationships"], self)
         elif req.status_code == 404:
             raise NoContentError(req)
         else:
@@ -252,7 +259,8 @@ class MangaDex:
     def transform_ids(self, obj: str, content: List[int]) -> Dict:
         """Gets uuids from legacy ids."""
         data = {"type": obj, "ids": content}
-        post = self.session.post(f"{self.api}/legacy/mapping", data=json.dumps(data))
+        post = self.session.post(f"{self.api}/legacy/mapping", data=json.dumps(data),
+                                 headers={"Content-Type": "application/json"})
         if post.status_code == 200:
             resp = post.json()
             return {x["data"]["attributes"]["legacyId"]: x["data"]["attributes"]["newId"] for x in resp}
