@@ -3,11 +3,12 @@ class Author:
     __slots__ = ("id", "name", "image", "bio", "created_at", "updated_at", "client")
 
     def __init__(self, data, rel, client):
-        self.id = data["id"]
-        self.name = data["attributes"]["name"]
-        self.image = data["attributes"]["imageUrl"]
-        self.bio = data["attributes"]["biography"]
-        self.created_at = data["attributes"]["createdAt"]
-        self.updated_at = data["attributes"]["updatedAt"]
+        self.id = data.get("id")
+        _attrs = data.get("attributes")
+        self.name = _attrs.get("name")
+        self.image = _attrs.get("imageUrl")
+        self.bio = _attrs.get("biography")
+        self.created_at = _attrs.get("createdAt")
+        self.updated_at = _attrs.get("updatedAt")
         self.client = rel  # Dummy assignment for the search helper to work properly. Does not affect the object.
         self.client = client
